@@ -46,7 +46,7 @@ CAPABILITIES = ['flow_stats',
                 'queue_stats',
                 'arp_match_ip',
                 'port_blocked'
-               ]
+                ]
 
 PORT_CONFIG = ["port_down",
                "no_stp",
@@ -64,7 +64,7 @@ PORT_STATE = ["link_down",
               "stp_learn",
               "stp_forward",
               "stp_block"
-             ]
+              ]
 
 PORT_FEATURES = ["rate_10mb_hd",
                  "rate_10mb_fd",
@@ -82,7 +82,7 @@ PORT_FEATURES = ["rate_10mb_hd",
                  "autoneg",
                  "pause",
                  "pause_asym"
-                ]
+                 ]
 
 FLOW_MOD_CMD = ["add",
                 "modify",
@@ -141,69 +141,68 @@ LINK_STATE = ["link_down",
 
 OPERATION = ["ADD", "CHANGE", "DELETE", "MOVE"]
 
-ENUMS = [ ETHERNET,
-          VERSION,
-          ACTIONS,
-          CAPABILITIES,
-          PORT_CONFIG,
-          PORT_STATE,
-          PORT_FEATURES,
-          FLOW_MOD_CMD,
-          FLOW_MOD_FLAGS,
-          IP_PROTOCOL,
-          ICMP_V6_TYPE,
-          MATCH_MODE,
-          ICMP_V6_TYPE,
-          MATCH_MODE,
-          IPV6_EXTHDR,
-          METER_FLAGS,
-          METER_TYPE,
-          GROUP_TYPE,
-          COMMANDS,
-          LINK_STATE,
-          OPERATION
-        ]
+ENUMS = [ETHERNET,
+         VERSION,
+         ACTIONS,
+         CAPABILITIES,
+         PORT_CONFIG,
+         PORT_STATE,
+         PORT_FEATURES,
+         FLOW_MOD_CMD,
+         FLOW_MOD_FLAGS,
+         IP_PROTOCOL,
+         ICMP_V6_TYPE,
+         MATCH_MODE,
+         ICMP_V6_TYPE,
+         MATCH_MODE,
+         IPV6_EXTHDR,
+         METER_FLAGS,
+         METER_TYPE,
+         GROUP_TYPE,
+         COMMANDS,
+         LINK_STATE,
+         OPERATION
+         ]
 
-METHODS = [ "factory", "to_json_string", "to_dict"]
+METHODS = ["factory", "to_json_string", "to_dict"]
 KEYWORDS = ["self"]
 
-JSON_MAP = {
-             'datapath': 'Datapath',
-             'meter_features': 'MeterFeatures',
-             'group_features': 'GroupFeatures',
-             'port': 'Port',
-             'meter': 'Meter',
-             'flow': 'Flow',
-             'group': 'Group',
-             'cluster': 'Cluster',
-             'packet': 'Packet',
-             'path': 'Path',
-             'app': 'App',
-             'license' : 'License',
-             'support_report': None,
-             'observation': 'Observation',
-             'nexthop': 'NextHop'
-           }
+JSON_MAP = {'datapath': 'Datapath',
+            'meter_features': 'MeterFeatures',
+            'group_features': 'GroupFeatures',
+            'port': 'Port',
+            'meter': 'Meter',
+            'flow': 'Flow',
+            'group': 'Group',
+            'cluster': 'Cluster',
+            'packet': 'Packet',
+            'path': 'Path',
+            'app': 'App',
+            'license': 'License',
+            'support_report': None,
+            'observation': 'Observation',
+            'nexthop': 'NextHop'
+            }
 
-PLURALS = { 'datapaths': JSON_MAP['datapath'],
-            'controller_stats': 'ControllerStats',
-            'stats': 'Stats',
-            'ports' : JSON_MAP['port'],
-            'meters': JSON_MAP['meter'],
-            'flows': JSON_MAP['flow'],
-            'groups': JSON_MAP['group'],
-            'clusters': JSON_MAP['cluster'],
-            'links': 'Link',
-            'nodes': 'Node',
-            'arps': 'Arp',
-            'lldp_suppressed': 'LldpProperties',
-            'observations': JSON_MAP['observation'],
-            'packets': JSON_MAP['packet'],
-            'apps': JSON_MAP['app'],
-            'licenses': JSON_MAP['license'],
-            'paths': JSON_MAP['path'],
-            'nexthops': JSON_MAP['nexthop']
-          }
+PLURALS = {'datapaths': JSON_MAP['datapath'],
+           'controller_stats': 'ControllerStats',
+           'stats': 'Stats',
+           'ports': JSON_MAP['port'],
+           'meters': JSON_MAP['meter'],
+           'flows': JSON_MAP['flow'],
+           'groups': JSON_MAP['group'],
+           'clusters': JSON_MAP['cluster'],
+           'links': 'Link',
+           'nodes': 'Node',
+           'arps': 'Arp',
+           'lldp_suppressed': 'LldpProperties',
+           'observations': JSON_MAP['observation'],
+           'packets': JSON_MAP['packet'],
+           'apps': JSON_MAP['app'],
+           'licenses': JSON_MAP['license'],
+           'paths': JSON_MAP['path'],
+           'nexthops': JSON_MAP['nexthop']
+           }
 
 CLASS_MAP = {'ControllerStats': {'lost': 'Counter',
                                  'packet_in': 'Counter',
@@ -223,7 +222,7 @@ CLASS_MAP = {'ControllerStats': {'lost': 'Counter',
                         'dhcp': 'Dhcp',
                         'icmp': 'Icmp',
                         'icmpv6': 'Icmpv6'}
-}
+             }
 
 
 class JsonObjectFactory(object):
@@ -244,6 +243,7 @@ class JsonObjectFactory(object):
             JsonObjectFactory.add_factory(id, eval(id))
         return JsonObjectFactory.factories[id].factory(data)
 
+
 class JsonObject(object):
 
     """ This is the base class for all HP SDN Client data types."""
@@ -259,7 +259,7 @@ class JsonObject(object):
     def to_dict(self):
         data = {}
         attributes = [attr for attr in dir(self)
-                      if not callable(getattr(self,attr))
+                      if not callable(getattr(self, attr))
                       and not attr.startswith("__")]
         for attr in attributes:
             if getattr(self, attr):
@@ -297,7 +297,7 @@ class JsonObject(object):
 
     def __eq__(self, other):
         attributes = [attr for attr in dir(self)
-                      if not callable(getattr(self,attr))
+                      if not callable(getattr(self, attr))
                       and not attr.startswith("__")]
         for attr in attributes:
             try:
@@ -312,6 +312,7 @@ class JsonObject(object):
 
 ### OpenFlow ###
 
+
 class Datapath(JsonObject):
     """ Datapath (JsonObject)
 
@@ -329,12 +330,14 @@ class Datapath(JsonObject):
         self.device_ip = kwargs.get('device_ip', None)
         self.device_port = kwargs.get('device_port', None)
 
+
 class DatapathControllers(JsonObject):
     """ A controller, from a datapath point of view """
     def __init__(self, **kwargs):
         self.master = kwargs.get('master', None)
         self.slaves = kwargs.get('slaves', [])
 
+
 class MeterFeatures(JsonObject):
     def __init__(self, **kwargs):
         self.flags = kwargs.get("flags", None)
@@ -343,6 +346,7 @@ class MeterFeatures(JsonObject):
         self.max_meters = kwargs.get("max_meters", None)
         self.types = kwargs.get("types", None)
 
+
 class GroupFeatures(JsonObject):
     """ Docstirg here"""
     def __init__(self, **kwargs):
@@ -351,6 +355,7 @@ class GroupFeatures(JsonObject):
         self.max_groups = kwargs.get("max_groups", None)
         self.types = kwargs.get("types", None)
 
+
 class Port(JsonObject):
     """ Port (JsonObject)
 
@@ -370,6 +375,7 @@ class Port(JsonObject):
         self.supported_features = kwargs.get('supported_features', [])
         self.peer_features = kwargs.get('peer_features', [])
 
+
 class Flow(JsonObject):
     """ Flow (JsonObject)
 
@@ -414,19 +420,19 @@ class Flow(JsonObject):
                     new_action = {}
                     keys = []
                     for d in data[key]:
-                        keys.extend([(k,v) for k,v in d.iteritems()])
+                        keys.extend([(k, v) for k, v in d.items()])
                     num_keys = range(len(keys))
 
                     duplicates = {}
 
                     for i in num_keys:
                         key_name = keys[i][0]
-                        if duplicates.has_key(key_name):
+                        if key_name in duplicates:
                             duplicates[key_name].append(i)
                         else:
                             duplicates[key_name] = [i]
 
-                    for k,v in duplicates.iteritems():
+                    for k, v in duplicates.items():
                         if len(v) > 1:
                             new_action[k] = [keys[i][1] for i in v]
                         else:
@@ -444,6 +450,7 @@ class Flow(JsonObject):
             pass
         return cls(**data)
 
+
 class Match(JsonObject):
     """ Match (JsonObject)
 
@@ -501,7 +508,7 @@ class Match(JsonObject):
         """
         data = []
         attributes = [attr for attr in dir(self)
-                      if not callable(getattr(self,attr))
+                      if not callable(getattr(self, attr))
                       and not attr.startswith("__")]
         for attr in attributes:
             if getattr(self, attr):
@@ -510,6 +517,7 @@ class Match(JsonObject):
                 data.append(tmp)
         return data
 
+
 class Action(JsonObject):
     """ Action (JsonObject)
 
@@ -546,7 +554,7 @@ class Action(JsonObject):
         """
         data = []
         attributes = [attr for attr in dir(self)
-                      if not callable(getattr(self,attr))
+                      if not callable(getattr(self, attr))
                       and not attr.startswith("__")]
         for attr in attributes:
             if attr == "output":
@@ -567,6 +575,7 @@ class Action(JsonObject):
                     data.append(tmp)
         return data
 
+
 class Instruction(JsonObject,):
     """ Instruction (JsonObject)
 
@@ -582,6 +591,7 @@ class Instruction(JsonObject,):
         self.meter = kwargs.get('meter', None)
         self.experimenter = kwargs.get('experimenter', None)
 
+
 class MeterStats(JsonObject):
     """ MeterStats (JsonObject)
 
@@ -597,6 +607,7 @@ class MeterStats(JsonObject):
         self.duration_nsec = kwargs.get('duration_nsec', None)
         self.band_stats = kwargs.get('band_stats', [])
 
+
 class BandStats(JsonObject):
     """ BandStats (JsonObject)
 
@@ -607,6 +618,7 @@ class BandStats(JsonObject):
         self.packet_count = kwargs.get('packet_count', None)
         self.byte_count = kwargs.get('byte_count', None)
 
+
 class Meter(JsonObject):
     """ Meter (JsonObject)
 
@@ -619,6 +631,7 @@ class Meter(JsonObject):
         self.flags = kwargs.get('flags', [])
         self.bands = kwargs.get('bands', [])
 
+
 class MeterBand(JsonObject):
     """ MeterBand (JsonObject)
 
@@ -632,6 +645,7 @@ class MeterBand(JsonObject):
         self.prec_level = kwargs.get('prec_level', None)
         self.experimenter = kwargs.get('experimenter', None)
 
+
 class Group(JsonObject):
     """ Group (JsonObject)
 
@@ -639,7 +653,7 @@ class Group(JsonObject):
 
     """
     def __init__(self, **kwargs):
-        self.id = kwargs.get('id',None)
+        self.id = kwargs.get('id', None)
         self.properties = kwargs.get('properties', None)
         self.ref_count = kwargs.get('ref_count', None)
         self.packet_count = kwargs.get('packet_count', None)
@@ -650,6 +664,7 @@ class Group(JsonObject):
         self.type = kwargs.get('type', None)
         self.buckets = kwargs.get('buckets', [])
 
+
 class Bucket(JsonObject):
     """ Bucket (JsonObject)
 
@@ -662,6 +677,7 @@ class Bucket(JsonObject):
         self.watch_port = kwargs.get('watch_port', None)
         self.actions = kwargs.get('actions', [])
 
+
 class Stats(JsonObject):
     """ Stats (JsonObject)
 
@@ -699,6 +715,7 @@ class PortStats(JsonObject):
         self.rx_frame_err = kwargs.get('rx_frame_err', None)
         self.rx_over_err = kwargs.get('rx_over_err', None)
 
+
 class GroupStats(JsonObject):
     """ GroupStats (JsonObject)
 
@@ -716,6 +733,7 @@ class GroupStats(JsonObject):
 
 ### Network Services ###
 
+
 class Cluster(JsonObject):
     """ Cluster (JsonObject)
 
@@ -726,6 +744,7 @@ class Cluster(JsonObject):
         self.uid = kwargs.get('uid', None)
         self.links = kwargs.get('links', [])
 
+
 class Link(JsonObject):
     """ Link (JsonObject)
 
@@ -739,6 +758,7 @@ class Link(JsonObject):
         self.dst_port = kwargs.get('dst_port', None)
         self.info = kwargs.get('info', [])
 
+
 class LinkInfo(JsonObject):
     """ LinkInfo (JsonObject)
 
@@ -754,6 +774,7 @@ class LinkInfo(JsonObject):
 
 #lldp_suppressed == list of LldpProperties
 
+
 class LldpProperties(JsonObject):
     """ LldpProperties (JsonObject)
 
@@ -764,6 +785,7 @@ class LldpProperties(JsonObject):
         self.dpid = kwargs.get('dpid', None)
         self.ports = kwargs.get('ports', [])
 
+
 class Arp(JsonObject):
     """ Arp (JsonObject)
 
@@ -775,6 +797,7 @@ class Arp(JsonObject):
         self.mac = kwargs.get('mac', None)
         self.vid = kwargs.get('vid', None)
 
+
 class Node(JsonObject):
     """ Node (JsonObject)
 
@@ -788,6 +811,7 @@ class Node(JsonObject):
         self.dpid = kwargs.get('dpid', None)
         self.port = kwargs.get('port', None)
 
+
 class Path(JsonObject):
     """ Path (JsonObject)
 
@@ -798,6 +822,7 @@ class Path(JsonObject):
         self.cost = kwargs.get('cost', None)
         self.links = kwargs.get('links', [])
 
+
 class LinkSync(JsonObject):
     """ LinkSync ()
 
@@ -812,6 +837,7 @@ class LinkSync(JsonObject):
         self.d_port = kwargs.get('d_port', None)
         self.info = kwargs.get('info', None)
 
+
 class ClusterSync(JsonObject):
     """ ClusterSync()
 
@@ -824,6 +850,7 @@ class ClusterSync(JsonObject):
         self.root = kwargs.get("root", None)
         self.nodes = kwargs.get("nodes", None)
 
+
 class NodeSync(JsonObject):
     """ NodeSync()
 
@@ -834,6 +861,7 @@ class NodeSync(JsonObject):
         self.dpid = kwargs.get('dpid', None)
         self.links = kwargs.get('links', None)
 
+
 class NodeLink(JsonObject):
     """ NodeLink()
 
@@ -849,6 +877,7 @@ class NodeLink(JsonObject):
         self.s_pt_state = kwargs.get('s_pt_state', None)
         self.d_pt_state = kwargs.get('d_pt_state', None)
 
+
 class NodeMessage(JsonObject):
     """ NodeMessage()
 
@@ -865,6 +894,7 @@ class NodeMessage(JsonObject):
 
 #Lldp_sync == a list of LldpProperties
 
+
 class Btree(JsonObject):
     """ Btree()
 
@@ -876,6 +906,7 @@ class Btree(JsonObject):
         self.links = kwargs.get('links', [])
         self.costs = kwargs.get('costs', [])
 
+
 class BtreeLink(JsonObject):
     """ BtreeLink()
 
@@ -887,6 +918,7 @@ class BtreeLink(JsonObject):
         self.dpid = kwargs.get('dpid', None)
         self.link = kwargs.get('link', [])
 
+
 class TreeLink(JsonObject):
     """ TreeLink()
 
@@ -900,6 +932,7 @@ class TreeLink(JsonObject):
         self.d_dpid = kwargs.get('d_dpid', None)
         self.d_port = kwargs.get('d_port', None)
 
+
 class Cost(JsonObject):
     """ Cost()
 
@@ -913,6 +946,7 @@ class Cost(JsonObject):
 
 ### Core ###
 
+
 class AuditLogEntry(JsonObject):
     """ AuditLogEntry()
 
@@ -928,6 +962,7 @@ class AuditLogEntry(JsonObject):
         self.activity = kwargs.get("activity", None)
         self.description = kwargs.get("description", None)
 
+
 class Alert(JsonObject):
     """ Alert()
 
@@ -958,6 +993,7 @@ class AlertTopic(JsonObject):
         self.org = kwargs.get("org", None)
         self.desc = kwargs.get("desc", None)
 
+
 class AlertTopicListener(JsonObject):
     """ AlertTopicListener()
 
@@ -996,6 +1032,7 @@ class Config(JsonObject):
         self.trim_enabled = kwargs.get("trim_enabled", [])
         self.trim_interval_hours = kwargs.get("trim_interval_hours", [])
 
+
 class ConfigItem(JsonObject):
     """ ConfigItem()
 
@@ -1008,6 +1045,7 @@ class ConfigItem(JsonObject):
         self.def_val = kwargs.get("def_val", None)
         self.desc = kwargs.get("desc", None)
 
+
 class SupportEntry(JsonObject):
     """ SupportEntry()
 
@@ -1020,6 +1058,7 @@ class SupportEntry(JsonObject):
         self.id = kwargs.get("id", None)
         self.content = kwargs.get("content", [])
 
+
 class System(JsonObject):
     """ A system """
     def __init__(self, **kwargs):
@@ -1027,12 +1066,14 @@ class System(JsonObject):
         self.version = kwargs.get("version", None)
         self.role = kwargs.get("role", None)
         self.core_data_version = kwargs.get("core_data_version", None)
-        self.core_data_version_timestamp = kwargs.get( \
-            "core_data_version_timestamp", None)
+        self.core_data_version_timestamp = kwargs.get(
+            "core_data_version_timestamp", None
+        )
         self.time = kwargs.get("time", None)
         self.self_ = kwargs.get("self_", None)
         self.status = kwargs.get("status", None)
 
+
 class ControllerNode(JsonObject):
     """ A Controller Node """
 
@@ -1040,13 +1081,15 @@ class ControllerNode(JsonObject):
         self.ip = kwargs.get("ip", None)
         self.name = kwargs.get("name", None)
 
+
 class Region(JsonObject):
     """ A Region """
     def __init__(self, **kwargs):
         self.uid = kwargs.get("uid", None)
         self.master = kwargs.get("master", None)
         self.slaves = kwargs.get("slaves", [])
-        self.devices = kwargs.get("devices",[])
+        self.devices = kwargs.get("devices", [])
+
 
 class Team(JsonObject):
     """ Team()
@@ -1061,6 +1104,7 @@ class Team(JsonObject):
         self.version = kwargs.get("version")
         self.systems = kwargs.get("systems")
 
+
 class TeamSystem(JsonObject):
     """ TeamSystems()
 
@@ -1094,6 +1138,7 @@ class Metric(JsonObject):
         self.summary_interval = kwargs.get("summary_interval", None)
         self.priming_value = kwargs.get("priming_value", None)
 
+
 class MetricUpdate(JsonObject):
     """ Metric()
 
@@ -1112,6 +1157,7 @@ class MetricUpdate(JsonObject):
         self.mark = kwargs.get("mark", None)
         self.type = kwargs.get("type", None)
 
+
 class License(JsonObject):
     """ A License """
     def __init__(self, **kwargs):
@@ -1128,6 +1174,7 @@ class License(JsonObject):
         self.license_status = kwargs.get("license_status", None)
         self.deactivated_key = kwargs.get("deactivated_key", None)
 
+
 class Packet(JsonObject):
     """ Packet()
 
@@ -1147,6 +1194,7 @@ class Packet(JsonObject):
         self.udp = kwargs.get("udp", None)
         self.dhcp = kwargs.get("dhcp", None)
 
+
 class Ethernet(JsonObject):
     """ Ethernet()
 
@@ -1161,6 +1209,7 @@ class Ethernet(JsonObject):
         self.vlan_vid = kwargs.get("vlan_vid", None)
         self.vlan_pcp = kwargs.get("vlan_pcp", None)
 
+
 class Ip(JsonObject):
     """ Ip()
 
@@ -1176,6 +1225,7 @@ class Ip(JsonObject):
         self.ip_ecn = kwargs.get("ip_ecn", None)
         self.ip_ident = kwargs.get("ip_ident", 0)
 
+
 class Icmp(JsonObject):
     """ Icmp()
 
@@ -1186,6 +1236,7 @@ class Icmp(JsonObject):
     def __init__(self, **kwargs):
         self.icmp_code = kwargs.get("icmp_code", None)
 
+
 class Ipv6(JsonObject):
     """ Ipv6()
 
@@ -1200,6 +1251,7 @@ class Ipv6(JsonObject):
         self.ip_dscn = kwargs.get("ip_dscn", None)
         self.ip_hop_limit = kwargs.get("ip_hop_limit", None)
 
+
 class Icmpv6(JsonObject):
     """ Icmp()
 
@@ -1214,6 +1266,7 @@ class Icmpv6(JsonObject):
         self.override = kwargs.get("override", None)
         self.target_address = ('target_address', None)
 
+
 class Tcp(JsonObject):
     """ Tcp()
 
@@ -1225,6 +1278,7 @@ class Tcp(JsonObject):
         self.tcp_dst = kwargs.get("tcp_dst", None)
         self.tcp_src = kwargs.get("tcp_src", None)
 
+
 class Udp(JsonObject):
     """ Udp()
 
@@ -1236,6 +1290,7 @@ class Udp(JsonObject):
         self.udp_dst = kwargs.get("udp_dst", None)
         self.udp_src = kwargs.get("udp_src", None)
 
+
 class Dhcp(JsonObject):
     """ Dhcp()
 
@@ -1253,6 +1308,7 @@ class Dhcp(JsonObject):
         self.client_mac = kwargs.get("client_mac", None)
         self.options = kwargs.get("options", None)
 
+
 class DhcpOptions(JsonObject):
     """ DhcpOptions()
 
@@ -1264,6 +1320,7 @@ class DhcpOptions(JsonObject):
         self.parameter_request_list = kwargs.get("parameter_request_list",
                                                  None)
 
+
 class App(JsonObject):
     """ An app """
     def __init__(self, **kwargs):
@@ -1275,6 +1332,7 @@ class App(JsonObject):
         self.vendor = kwargs.get("vendor", None)
         self.version = kwargs.get("version", None)
 
+
 class AppHealth(JsonObject):
     """ An app health object """
     def __init__(self, **kwargs):
@@ -1284,12 +1342,14 @@ class AppHealth(JsonObject):
         self.state = kwargs.get("state", None)
         self.status = kwargs.get("status", None)
 
+
 class MetricApp(JsonObject):
     """ An application with metering data on disk """
     def __init__(self, **kwargs):
         self.app_id = kwargs.get("app_id", None)
         self.app_name = kwargs.get("app_name", None)
 
+
 class MetricValues(JsonObject):
     """ The metric values """
     def __init__(self, **kwargs):
@@ -1298,6 +1358,7 @@ class MetricValues(JsonObject):
         self.datapoint_count = kwargs.get("datapoint_count", None)
         self.datapoints = kwargs.get("datapoints", [])
 
+
 class DataPoint(JsonObject):
     """ A datapoint """
     def __init__(self, **kwargs):
@@ -1305,11 +1366,13 @@ class DataPoint(JsonObject):
         self.milliseconds_span = kwargs.get("milliseconds_span", None)
         self.update_time = kwargs.get("upate_time", None)
 
+
 class NextHop(JsonObject):
     def __init__(self, **kwargs):
         self.dpid = kwargs.get("dpid", None)
         self.out_port = kwargs.get("out_port", None)
 
+
 class ControllerStats(JsonObject):
     def __init__(self, **kwargs):
         self.uid = kwargs.get("uid", None)
@@ -1320,11 +1383,13 @@ class ControllerStats(JsonObject):
         self.packet_in = kwargs.get("packet_in", None)
         self.packet_out = kwargs.get("packet_out", None)
 
+
 class Counter(JsonObject):
     def __init__(self, **kwargs):
         self.packets = kwargs.get("packets", None)
         self.bytes = kwargs.get("bytes", None)
 
+
 class Observation(JsonObject):
     def __init__(self, **kwargs):
         self.dpid = kwargs.get("dpid", None)
@@ -1332,4 +1397,4 @@ class Observation(JsonObject):
         self.packet_uid = kwargs.get("packet_uid", None)
         self.status = kwargs.get("status", None)
 
-CLASS_LIST = [s() for s in JsonObject.__subclasses__()] #pylint: disable E1101
+CLASS_LIST = [s() for s in JsonObject.__subclasses__()]
